%
%                            URI_GSO-Dock

% $Log: gsodock.m,v $
% Revision 1.1  1999/07/22 19:28:05  kwoklin
% Add R. Platner's local data files in.   klee
%

% $Id: gsodock.m,v 1.1 1999/07/22 19:28:05 kwoklin Exp $
% Ruth Platner  07/06/99

%N.B. Time is stored on the server in units of days since 1899-30-12 00:00:00";
%
% FUNCTIONS -- REQUIRED
GetFunctionName = 'getgsod';

% FUNCTIONS -- OPTIONAL
CatalogServer = nan;
URL_m_File = 'gsodocku';

% VARIABLES -- OPTIONAL
Server = 'http://euros.gso.uri.edu/cgi-bin/dods/nph-jg/gsodock';

% VARIABLES -- REQUIRED
LonRange = [-71.7384 -71.7384];
LatRange = [41.2453 41.2453];
TimeRange = [1996.4 1997.5];
DepthRange = [-785.11 3.5];   % [0.0 3.5]/[735.08 785.11]
Resolution = nan;

DataName = 'Water Column/MET - GSO Dock 10 minute Time-Series - URI';
TimeName = str2mat('Year','Month','Day','Hour','Min','CompTime');
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = '';
DepthUnits = '             Depth (meters)            / Barometric Pressure (mmHg) ';
DataTime = 1899+363/365;
OptionalVariables = NaN;

% these names tie in to the browser as recognized common strings
% linking different datasets
DodsName1 = str2mat('lat','lon','CompTime');
SelectableVariables = str2mat('Sea_Temp','Salinity','Oxygen_Saturation','pH_Value', ...
'Air_Temp','Wind_Speed','Wind_Dir','Barometric_Pres','Tidal_Height','Radiation');
% there must be one DODSNAME for each selectable variable
% Add year/month/day/hour/minute as returned variables.   klee 06/07/99
DodsName = str2mat('WatTemp','Salinity','Oxygen','pH', ...
'AirTemp','WindSp','WindDir','BarPres','Depth','Solar');

% note: DataNull is applied *before* scaling
DataNull = [NaN NaN NaN NaN ...
           -999 -999 -999 -999 -999 -999 -999 -999 -999 -999];

Acknowledge = sprintf('%s\n\n%s\n%s\n%s', ...
    [ 'The authors of this dataset are A. Magnuson, D. R. Kester ',...
      'and M. Fox. 1999.', ...
      'The data were provided by the University of Rhode Island ', ...
      '(http://euros.gso.uri.edu/dods/data/gsodock/)',...
      'and accessed via the Distributed Oceanographic Data System ',...
      '(DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citations:  Magnuson, Andrea.  1997.  Chemical Variability ',...
      'in Coastal and Mixed Layer Waters. Ph.D. Thesis.  Graduate ',...
      'Schoolof Oceanography, University of Rhode Island, ',...
      'Narragansett. 325 pp.'],...
    [ 'Magnuson A and Kester D R.  1999. Annual cycle in esturaine ',...
      'waters near the entrance of Narragansett Bay: 1. Varia-',...
      'bility from hours to seasons. To be submitted to Estuarine, ',...
      'Shelf, and Coastal Science.'],...
    [ 'Magnuson A and Kester D R.  1999. Annual cycle in esturaine ',...
      'waters near the entrance of Narragansett Bay: 2.  Processes ',...
      'controlling variability. To be submitted to Estuarine, ',...
      'Shelf, and Coastal Science.']);
Data_Use_Policy = [];

Comments1 = sprintf('%s\n','',...
 '                                GSO Pier Time-Series',...
 '      ',...
 '           Parameter         Description                    Units',...
'      --------------------------------------------------------------------------',...
'            Year',...
'            Month',...
'            Day',...
'            Hour/Min',...
'            JulianDay         yearday                        decimal day       ',...
'            CompTime          date based on 1899+363/365     decimal day       ',... 
'            WatTemp           sea temperature                degrees Celcius   ',...
'            Salinity          salinity                       PSU               ',...
'            Oxygen            dissoloved oxygen              percent saturation ',...
'            pH                pH calibrated on NBS buffer scale                ',...
'            AirTemp           temperature                    degrees Celcius   ',...
'            WindSp            wind speed                     m/s               ',...
'            WindDir           wind direction                 degrees True      ',...
'            BarPres           barometric pressure            mmHg              ',...
'            Depth             water depth (tidal height)     meters            ',...
'            Solar             solar radiation                W/M2              ',...                                    
'       ',...
 '           This time-series data set consists of water column and meteorological',...
 '      measurements at the University of Rhode Island, Narragansett Bay Campus,',...
 '      Graduate School of Oceanography Pier. The water column variables were',...
 '      measured using YSI Model 6000 multi-sensor sondes. These sondes measured',...
 '      seawater temperature, salinity (via conductivity), dissolved oxygen partial',...
 '      pressure (with the rapid-pulse polarographic sensor, pH,  and pressure, from',...
 '      which water level variations can be obtained. The meteorological',...
 '      measurements were made with Sensormetrics sensors for air temperature, wind',...
 '      speed and direction, barometric pressure, and solar radiation (with a Licor',...
 '      solar radiation sensor, not PAR photosynthetically available radiation).',...
 '      ',...
 '           The YSI sondes were suspended from the GSO Pier through a hole in pier',...
 '      deck located within the MERL pump house on the pier.  The sondes were',...
 '      positioned at a fixed distance above the seafloor.  The waters measured were',...
 '      about 1-2 m below the sea surface depending on the stage of the tide.  The',...
 '      water depth at this location was about 3-4 m; it increases rapidly to 7-8 m',...
 '      within 20 m east of the site.  The wind sensors were located on a mast 10 m',...
 '      above the water surface.  Air temperature and barometric pressure were',...
 '      located in a ventilated wooden shelter mounted on the roof of the MERL pump',...
 '      house on the pier.  The solar sensor was mounted on the top surface of the',...
 '      wooden shelter.');
Comments2 = sprintf('%s\n','',...
 '           This data set is part of an uninterrupted year-long time-series',...
 '      obtained by Ms. Andrea Magnuson as part of her Ph.D. studies (Magnuson,',...
 '      1997).  Two Model 6000 sondes were deployed at the same location for this',...
 '      time-series to have redundancy, and to allow for continuity when sondes were',...
 '      retrieved for laboratory re-calibration and removal of biofouling.  The',...
 '      redundancy also provided data continuity if one sonde became inoperable',...
 '      during a deployment. The measurement interval was every 10 minutes.  Dr.',...
 '      Magnuson re-calibrated the sensors at weekly intervals.  She processed the',...
 '      data and merged the water column and meteorological data sets.  The data set',...
 '      was formatted by Dr. Mary F. Fox for entry into DODS (the Distributed Ocean',...
 '      Data System developed by Prof. Peter Cornillon).',...
 '      ',...
 '           The data set includes the following variables: year; month; day; hour;',...
 '      minute; time as a decimal number used by spreadsheet programs (for date,',...
 '      hour, minute, second); day number of the year in decimal form that includes',...
 '      time of day (sometimes called Julian Day); seawater temperature (degrees',...
 '      Celcius) ; PSU salinity; dissolved oxygen partial pressure as percent',...
 '      saturation; pH calibrated on the NBS buffer scale;  air temperature (degrees',...
 '      Celcius); wind speed (m/s); wind direction (degrees True); barometric',...
 '      pressure (mm of Hg); and solar radiation (watts per square meter).');
Comments3 = sprintf('%s\n','',...
 '           These data were collected as part of a research project sponsored by',...
 '      the Office of Naval Research in a grant to Prof. Kester.  They are being',...
 '      used in a series of publications by Magnuson, Kester, and Fox to determine a',...
 '      number of physical, chemical, and biological processes in Narragansett Bay',...
 '      and Rhode Island Sound.  We encourage other investigators to make use of',...
 '      these data on an ancillary basis to better understand how their own',...
 '      observations in this area relate to environmental factors.  We would',...
 '      appreciate being notified when others make such use of these data.  We would',...
 '      be pleased to collaborate with other investigators who would like to perform',...
 '      analyses and publish results from these data that do not duplicate our work',...
 '      in progress.',...
 '      ',...
 '      For information on use of these data please contact:',...
 '      ',...
 '      Prof. Dana R. Kester',...
 '      Graduate School of Oceanography',...
 '      University of Rhode Island',...
 '      South Ferry Road',...
 '      Narragansett, RI 02882 USA',...
 '      ',...
 '      E-mail: dkester@gso.uri.edu',...
 '      ',...
 '      Data Status: Final',...
 '      ',...
 '      People Who Were Responsible for Collection, Processing, and Compilation of',...
 '      Data:',...
 '           Andrea Magnuson',...
 '           Dana Kester',...
 '           Mimi Fox');
Comments4 = sprintf('%s\n',...
        '   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Jul. 01, 1996 (1996.50000000)', ...
'         Ending_Date:    Jun. 30, 1997 (1997.49861112)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 71.7384 W ', ...
'              East Bounding Coordinate: 71.7384 W ', ...
'              South Bounding Coordinate: 41.2453 N ', ...
'              North Bounding Coordinate: 41.2453 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Prof. Dana R. Kester', ...
'               Graduate School of Oceanography',...
'               University of Rhode Island',...
'               South Ferry Road',...
'               Narragansett, RI 02882 USA',...
'               USA ', ...
'               Electronic Mail Address:INTERNET > dkester@gso.uri.edu',...
'         Address - collection, processing and compilation: ',...
'               Andrea Magnuson',...
'               Graduate School of Oceanography',...
'               University of Rhode Island',...
'               South Ferry Road',...
'               Narragansett, RI 02882 USA',...
'               USA ', ...
'               Electronic Mail Address:INTERNET > amags@gsosun1.gso.uri.edu',...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');
Comments = [Comments1 Comments2 Comments3 Comments4];
