%                Temperature Monthly Anomalies Data at PMEL archive.

% The preceding empty line is important.
%
% $Id: ncdcanom.m,v 1.14 1999/06/01 00:53:52 dbyrne Exp $

% $Log: ncdcanom.m,v $
% Revision 1.14  1999/06/01 00:53:52  dbyrne
%
%
% Many fixes in prep for AGU.  fth, htn, glk and prevu changed to use
% fileservers. -- dbyrne 99/05/31
%
% Revision 1.1  1999/05/28 18:05:31  kwoklin
% Shorten long comments.                klee
%
% Revision 1.13  1999/05/13 03:09:55  dbyrne
%
%
% Added Acknowledge and Data_Use_Policy to archive.m.  Fixed getxxx functions
% to use dodsmsg instead of stdout for errors/info.  Made ChangeLog so that it's
% in Emacs format.  All changes for release 3.0.0 -- dbyrne 99/05/12
%
% Revision 1.15  1999/05/13 01:24:17  root
% Added Acknowledge and Data_Use Policy.  Fixed some bugs.  Changed any
% messages to use to use 'dodsmsg' script instead of just displaying to stdout.
%
% Revision 1.14  1999/03/04 13:13:30  root
% All changes since AGU week.
%
% Revision 1.10  1998/11/18 19:57:02  dbyrne
%
%
% Second try.  Bug fixes to jpl pathfinder data, changed names of
% Reynolds datasets to clarify that one is a climatology and one is not.
%
% Revision 1.13  1998/11/05 16:01:53  root
% Changed LonVector and LatVector to be used if no Lon returned and tried the update function.
% DataScale and DataNull should now be optional!
%
% Revision 1.7  1998/09/14 01:32:56  dbyrne
% Elminated an inconsistency whereby the depth variable was not scaled
% and had no DataNull etc.  Added check for empty variables to plotscript.m
%
% Revision 1.12  1998/09/13 19:33:24  root
% updated DataNull &c.
%
% Revision 1.11  1998/09/13 19:21:24  root
% Eliminated an inconsistency in DataScale, DataRange, and DataNull, that
% Depth was not included!
%
% Revision 1.10  1998/09/12 15:27:47  root
% Fixed some small bugs.
%
% Revision 1.9  1998/09/12 09:36:27  root
% Fixing up TimeRanges.
%
% Revision 1.8  1998/09/11 08:16:08  dbyrne
% Longitude ranges were messed up in every archive.m file except the
% two I wrote myself.  To eliminate future confusion, 'LLon' 'Llat',
% 'Rlon' and 'Ulat' etc are being eliminated in favor of two-component
% vectors LonRange LatRange TimeRange DepthRange.
%
% Revision 1.7  1998/09/10 21:14:06  dbyrne
% Fixed some small bugs.
%
% Revision 1.6  1998/09/09 20:12:17  dbyrne
% Changing variable names to stay within 14 characters.
%
% Revision 1.5  1998/09/09 15:04:29  dbyrne
% Eliminating all global variables.
%
% Revision 1.4  1998/09/09 07:57:38  dbyrne
% replaced Data_Scale with DataScale, Data_Null with DataNull, and Data_Range
% with DataRange for consistency with other variables in the archive.m files.
%
% Revision 1.3  1998/09/09 07:40:22  dbyrne
% Replaced getrectangular with getrectg
%
% Revision 1.2  1998/09/09 07:34:22  dbyrne
% Eliminating ReturnedVariables
%
% Revision 1.1  1998/05/17 14:18:06  dbyrne
% *** empty log message ***
%
% Revision 1.3  1997/12/09 01:27:13  dbyrne
% Change misspelling of anomaly.
%
% Revision 1.2  1997/12/08 17:30:30  tom
% fixed 'nc' to correct 'nph-nc'
%
% Revision 1.1.1.1  1997/09/22 14:13:55  tom
% Imported Matlab GUI sources to CVS
%

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
URL_m_File = 'ncdcurl';
CatalogServer = 'monthly';

% VARIABLES -- OPTIONAL
Server = 'http://ferret.wrc.noaa.gov/cgi-bin/nph-nc/data/ncdc_monthly_anomalies.nc';
Nlon = 72;
Nlat = 37;

% VARIABLES -- REQUIRED
LonRange = [0.000 360.000];
LatRange = [-90.000 90.000];
TimeRange = [1856 1994];
DepthRange = [0.0 0.0];
DepthUnits = '';
Resolution = 555.0;                   % avg resolution

DataName = 'Temperatures - NCDC Monthly Anomalies - PMEL';   % Name of dataset
LongitudeName = 'LONG';
LatitudeName = 'LAT';
TimeName = 'TAX_15TH';
DepthName = '';
SelectableVariables = str2mat('Temp_Diff');
DodsName = str2mat('TEMP_ANOM');
% note: DataNull is applied *before* scaling
DataNull = [nan nan nan nan -999.9990234375];
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 0 1];
DataRange =   [NaN NaN; NaN NaN; -90 90; NaN NaN; -15.0 15.0];

Data_Use_Policy = '';
Acknowledge = sprintf('%s\n\n%s', ...
    [ 'The principal investigators in the production of these data', ...
      ' are C. Bruce Baker and Henry Diaz.  The data were provided',...
      ' by the Ferret development group of ', ...
      'the Thermal Modeling and Analysis Project at NOAA''s Pacific ',...
      'Marine Environmental Laboratory in Seattle Washington (PMEL: ',...
      'http://www.pmel.noaa.gov  Ferret: http://ferret.pmel.noa.gov)', ...
      ' and accessed via the Distributed Oceanographic ',...
      'Data System (DODS: ', ...
      'http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citations: Many: see text view.']);

% COMMENTS
Comments1 = sprintf('%s\n', ...
'                 NCDC Monthly Temperature Anomalies (1856-1994)', ...
'                             Held at NOAA/PMEL', ...
'    ', ...
'    The data set of Monthly Temperature Anomalies was developed at The National ', ...
'    Climatic Data Center (http://www.ncdc.noaa.gov/). In June 1995, ', ...
'    the NOAA Baseline Temperature dataset (land temperatures) was merged with a ', ...
'    gridded data set of sea surface temperatures to give a truly global anomaly ',...
'    product (http://www.ncdc.noaa.gov/onlineprod/landocean/monthly/form.html). ', ...
'    The ocean dataset is a compilation of data from the United Kingdom ', ...
'    Meteorological Office and the Comprehensive Oceanic and Atmospheric Data ', ...
'    Set (COADS). Monthly updates are performed by ERL using the GTS ship ', ...
'    reports. This dataset extends from 1856 to 1994. The data have been quality ', ...
'    controlled using an objective analysis scheme (Eischeid et al., JAM, Vol 34, ', ...
'    No. 12, pp2787-2795).  The data are gridded at 5x5deg resolution.', ...
'    ', ...
'    The complete temperature anomaly grid has an origin (indices 1,1) ', ...
'    corresponding to -90,0 and an extent (indices 32,72) given by 90,355.', ...
'    ');
Comments2 = sprintf('%s\n', ...
'    References:', ...
'    ', ...
'    The NOAA Global Climate Perspectives System: ', ...
'     (http://www.ncdc.noaa.gov/gcps/gcps.html)', ...
'    ',...
'    Baker, C. B., R. G. Quayle, and W. Wanlin 1993. The Influence of Night Time',...
'    Cloud Cover on the Observed Minimum Temperature in China. Sixth Conference',...
'    on Climate Variations, January 23-28, 1994, Nashville, TN.',...
'    ',...
'    Baker, C.B. and D.E. Brinegar, 1994. The Use of the Information Highway to',...
'    explore Climate Variability. The Second World Wide Web Conference, Chicago,',...
'    IL., October 17-20, 1994.',...
'    ',...
'    Baker, C.B., J.K. Eischeid, T.R. Karl, and H.F. Diaz, 1994: The quality',...
'    control of long-term climatological data using objective data analysis.',...
'    Preprints of AMS Ninth Conference on Applied Climatology, Dallas, TX.,',...
'    January 15-20, 1995.',...
'    ',...
'    Brinegar, Danny E. and C. Bruce Baker, 1995. The Global Climate Perspectives',...
'    System. Eleventh International Conference on Interactive Information and',...
'    Processing Systems for Meteorology, Oceanography, and Hydrology, January',...
'    15-20, 1995, Dallas, TX.',...
'    ',...
'    Brinegar, Danny E. and C. Bruce Baker, 1995. A Methodology for Data',...
'    Visualization on the WWW. NOAA Mosaic/WWW Workshop, Silver Spring, ',...
'    MD., June 13-14, 1995.',...
'    ',...
'    Brown, T.J., P.W. Mielke, Jr., and H.F. Diaz, 1993: Assessing global climate',...
'    trends using multi-response permutation procedures. Preprints of AMS Eighth',...
'    Conference on Applied Climatology, Anaheim, CA., January 17-22, 1993,',...
'    109-111.',...
'    ',...
'    Carroll, Tom and C. Bruce Baker, Xtract: Method to Browse, Extract and',...
'    Interrogate, Climatological Datasets Ninth International Conference on',...
'    Interactive Information and Processing Systems for Meteorology,',...
'    Oceanography, and Hydrology, 17-22 January 1993, Anaheim, CA. American',...
'    Meteorological Society, Boston MA',...
'    ',...
'    Carroll, Thomas J. and C. Bruce Baker, The Global Climate Perspectives',...
'    System: An Intelligent Database System for the Analysis of Environmental',...
'    Data Workshop on Climate Database Systems, 30 Aug.- 3 Sept., Hamburg,',...
'    Germany Deutsches Klimarechenzentrum GmbH',...
'    ');
Comments3 = sprintf('%s\n', ...
'    Diaz, H.F. and T.J. Brown, 1993. An objective classification of climatic',...
'    regions in the Pacific and Indian oceans. Proceedings of the Ninth Annual',...
'    Pacific Climate (PACLIM) Workshop, Asilomar, CA, April 21-24, 1992,',...
'    Technical Report 34 of the Interagency Ecological Studies Program for the',...
'    Sacramento-San Joaquin Estuary, 55-62.',...
'    ',...
'    Diaz, H. F., 1993. Approaches for regionalization of precipitation climates',...
'    in the context of global climate change monitoring. NATO Symposium on Global',...
'    Precipitation and Climate Change, Toulon, France. (Book in press).',...
'    ',...
'    Eischeid, J.K. and H.F. Diaz, 1993. An improved gridding technique for use',...
'    in climate monitoring. Preprints, Eighth AMS Conference on Applied',...
'    Climatology, Anaheim, CA, pp. 122-125.',...
'    ',...
'    Groisman, P.Ya. and D.R. Easterling: 1993: Variability and trends of',...
'    precipitation and snowfall over North America, in decadal-to-century-scale',...
'    climate variability, National Academy Press (in press).',...
'    ',...
'    Groisman, P.Ya. and D.R. Easterling, 1993: Variability and trends of',...
'    precipitation and snowfall over the United States and Canada, Journal of',...
'    Climate, (in press)',...
'    ',...
'    Groisman, P.Ya. and D.R. Legates, 1993: The accuracy of United States',...
'    precipitation data, Bull. Amer. Meteorol. Soc., (in press).',...
'        ',...
'    Groisman, P.Ya., T.R. Karl, and R.W. Knight, 1993: Observed snow cover',...
'    impact on the heat balance and the rise of continental spring temperatures,',...
'    Science, 14 January 1994, Vol 263, pp. 198-200.',...
'    ',...
'    Karl, Thomas R. and C. Bruce Baker, Global Warming Update Invited',...
'    Presentation at the 74th Annual Meeting of the American Meteorological',...
'    Society, 24-28 January 1994, Nashville, TN.',...
'    ',...
'    Karl, T. R., Jones, P. D., Knight, R. W., Kukla, G., Plummer, N., Razuvayev,',...
'    V., Gallo, K. P., Lindseay, J., Charlson, R. J., Peterson, T. C. 1993, A New',...
'    Perspective on Recent Global Warming: Asymmetric Trends of Daily Maximum',...
'    and Minimum Temperature, Bull. Amer. Meteor. Soc. Vol 74, No.6.',...
'    ',...
'    Karl, Thomas R., Robert G. Quayle and Pavel Ya. Groisman, 1993: Detecting',...
'    climate variations and change: New challenges for observing and data',...
'    management systems. Journal of Climate, 6, 1481-1494.',...
'    ');
Comments4 = sprintf('%s\n', ...
'    Karl, Thomas R., Pavel Ya. Groisman, Richard W. Knight, and Richard R. Heim,',...
'    Jr., 1993: Recent variations of snow cover and snowfall in North America and',...
'    their relation to precipitation and temperature variations. Journal of',...
'    Climate, 6, 1327-1344.',...
'    ',...
'    Karl, Thomas R., Philip D. Jones, Richard W. Knight, George Kukla, Neil',...
'    Plummer, Kevin P. Gallo, Janette Lindseay, and Robert J. Carlson, 1993:',...
'    Asymetric trends of daily maximum and minimum temperature: Empirical',...
'    evidence and possible causes. National Academy Press, (in press).',...
'    ',...
'    Kukla, George and Thomas R. Karl, 1993: Nighttime warming and the greenhouse',...
'    effect, Environmental Science & Technology, 27, 1468-1474.',...
'        ',...
'    Peterson, Thomas C. and David R. Easterling: 1993, Creation of homogeneous',...
'    composite climatological reference series. International Journal of',...
'    Climatology, in press.',...
'    ',...
'    (references above from http://www.ncdc.noaa.gov/gcps/gcpsrefs.html).', ...
'    ',...
'    PMEL FERRET Documentation on NCDC Monthly Temperature Anomalies ', ...
'    (http://ferret.wrc.noaa.gov/LAS/doc_htmls/ncdc_anom.cdf.html).');

Comments5 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1856 ', ...
'         Ending_Date:1994 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0.0 ', ...
'              East Bounding Coordinate:360.0 ', ...
'              South Bounding Coordinate:-90.00 ', ...
'              North Bounding Coordinate:+90.00 ', ...
'    Units:  Degrees Centigrade ', ...
'   ', ...
'    Point_of_Contact (Science) = ', ...
'         Electronic Mail Address:INTERNET > questions@ncdc.noaa.gov', ...
'   ', ...
'         Address: ', ...
'               C. Bruce Baker ', ...
'               NOAA/National Climate Data Center', ...
'               Global Climate Laboratory', ...
'               Federal Building', ...
'               151 Patton Avenue', ...
'               Asheville, North Carolina 28801-5001', ...
'               USA ', ...
'               Telephone: (704) 271-4430', ...
'         Electronic Mail Address:INTERNET > bbaker@ncdc.noaa.gov', ...
'   ');
Comments6 = sprintf('%s\n', ...
'         Address: ', ...
'               Henry Diaz ', ...
'               NOAA/ERL', ... 
'               Climate Diagnostics Center', ...
'               Mail Code: R/E/CD', ...
'               325 Broadway', ...
'               Boulder, Colorado 80803', ...
'               USA ', ...
'               Telephone: (303) 497-6649', ...
'               Fax: (303) 497-7013', ...
'         Electronic Mail Address:INTERNET > hfd@cdc.noaa.gov', ...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               Kevin O''Brien ', ...
'               NOAA/PMEL', ...
'               7600 Sand Point Way NE', ...
'               Seattle, Washington 98115-0070', ...
'               USA ', ...
'               Telephone: (206) 526-6751', ...
'         Electronic Mail Address:INTERNET > ferret@pmel.noaa.gov');

Comments = [Comments1 Comments2 Comments3 Comments4 Comments5 Comments6];



