%
%  Massachusetts Bay Circulation and Effluent Modeling

% The preceding empty line is important
% $Log: usgsmbay.m,v $
% Revision 1.6  1999/07/21 19:52:36  kwoklin
% Shorten citation list again.   klee
%
% Revision 1.5  1999/07/21 15:31:10  dbyrne
%
%
% Changed RT_Cell_Conc to Red_Tide_Cell_Conc.  dbyrne 99/07/21
%
% Revision 1.4  1999/07/20 20:07:05  dbyrne
%
%
% Changed citation list so that it is no longer cut off.  Browser will chop
% when screen size is reached.  -- dbyrne 99/07/20
%
% Revision 1.3  1999/07/19 19:12:05  kwoklin
% Shorten citation list.   klee
%
% Revision 1.1  1999/06/01 07:10:34  dbyrne
%
%
% Moved up from kleedata/
%
% Revision 1.2  1999/05/28 17:32:51  kwoklin
% Add all globec datasets. Fix depth representation for all globec datasets
% and nbneer dataset. Fix frontal display for htn and glkfront. Make use of
% getjgsta for all jgofs datasets. Point usgsmbay to new server. Point htn,
% glk, fth and prevu to new FF server.                                 klee
%

% $Id: usgsmbay.m,v 1.6 1999/07/21 19:52:36 kwoklin Exp $
%  klee 04/99

GetFunctionName = 'getusgsm';

Cat_m_File = 'usgsmcat';
URL_m_File = 'usgsmurl';
CatalogServer = str2mat('http://crusty.er.usgs.gov/cgi-bin/nph-nc/mbay/meandeer.cdf',...
                        'http://crusty.er.usgs.gov/cgi-bin/nph-nc/mbay/meanbb.cdf');
Server = str2mat('meanbb.cdf');

Nlon = 68;
Nlat = 68;
Ntime = 243;
Ndepth = 13;

LonRange = [-71.1390 -69.6230];
LatRange = [41.6479 43.2754];
TimeRange = [1989.7550342 1993.055780822];
TimeDivide = 1993.055780822;
DepthRange = [0 1];
DepthUnits = 'Sigma';
Resolution = 0.02;

DataName = 'Dino sample Datasets';
DataName = 'MODEL - Massachusetts Bay Circulation and Effluent Modeling - USGS'; 
TimeName = 'time';
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = 'sigma';
DepthUnits = 'Sigma';
SelectableVariables = str2mat('Sea_Surface_Height','Heat_Flux', ...
                      'Bathymetry','Salinity','Sea_Temp','Red_Tide_Cell_Conc', ...
                      str2mat('Horiz_Eddy_Visc','Vert_Visc'), ...
                      str2mat('U_Current','V_Current','W_Current'),...
                      'Bottom_Drag_Coef');
DodsName = str2mat('elev','heat_flux', ...
                   'depth','salt','temp','conc', ...
                   str2mat('am','km'),str2mat('u','v','w'), 'cd');

DataNull = [NaN NaN NaN NaN ...
            NaN ...    %elev
            NaN ...    %heat_flux
            -99999 ... %depth
            -32767 ... %salt
            -32767 ... %temp
            -32767 ... %conc
            -32767 ... %am
            -32767 ... %km
            NaN ...    %u
            NaN ...    %v
            NaN ...    %w
            NaN];      %cd
DataScale = [1993.2109589 0.002739726; NaN NaN; NaN NaN; NaN NaN; ...  %time, lon, lat, depth
             0 0.000122074040; 0 0.12207404; ...   %elev, heat_flux
             NaN NaN; 20 0.00061037019; 12.5 0.00053407392; 2000 0.061037019; ...  %depth, salt, temp, conc
             500 0.015259255; 0.1 0.000003051; ...   %am, km
             0 0.000091555; 0 0.000091555; 0 0.000000061; 0 1];   %u, v, w, cd
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; ...
             0 4; -1000 1000; NaN NaN; ...   %elev, heat_flux, depth
             0 20; -5 5; 0 100; 0 250; 0 0.01; ...   %salt, temp, conc, am, km
             0 3; 0 3; NaN NaN; NaN NaN];   %u, v, w, cd

Acknowledge = sprintf('%s\n\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n%s',...
    [ 'The author of this dataset is R. P. Signell.  ', ...
      'The data were provided by U. S. Geological Survey. ', ...
      '(http://crusty.er.usgs.gov/mbay/modeling.html) and accessed via ', ...
      'the Distributed Oceanographic Data System (DODS: ', ...
      'http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citation:  Signell, R. P., Modeling the seasonal circulation ',...
      'in Massachusetts Bay, In Estuarine and Coastal Modeling, ',...
      'Proceedings of the 3rd International Conference, edited by ',...
      'M. L. Spaulding, pp. 578--590. American Society of Civil ',...
      'Engineers, ASCE, New York, 1994. '],...
    [ 'Signell, R. P. and B. Butman, Modeling tidal exchange and ',...
      'dispersion in Boston Harbor, Journal of Geophysical Research, ',...
      '97, 15,591--16,606, 1992. '],...
    [ 'Signell, R. P., H. L. Jenter and A. F. Blumberg, Modeling the ',...
      'effects of relocating Boston''s sewage outfall, Journal of ',...
      'Estuarine, Coastal and Shelf Science, 1999 (in press).']);

Data_Use_Policy = [];

Comments1 = sprintf('%s\n', ...
'                               Contaminant Transport in Massachusetts Bay ',...
'  ',...
'                   Parameter     Description                  Units',...
'                 --------------------------------------------------------------------',...
'   ',...
'                   elev          Elevation                    meters',...
'                   heat_flux     Heat_flux                    watt/m^2',...
'                   depth         Bathymetry                   meters',...
'                   salt          Salinity                     ppt',...
'                   temp          Temperature                  degree C',...
'                   conc          RedTide_Cell_Concentration   percent',...
'                   am            Horizontal Eddy Viscosity    m^2/s',...
'                   km            Vertical Viscosity           m^2/s',...
'                   u             U1 Velocity                  m/s',...
'                   v             V1 Velocity                  m/s',...
'                   w             W Velocity                   m/s',...
'                   cd            Bottom Drag Coefficient      none',...
'  ',...
'The Boston Harbor Project will move the release treated effluent from the mouth of Boston Harbor to a battery of ',...
'diffusers 9 miles offshore. These diffusers will quickly mix the effluent with the surrounding seawater, diluting ',...
'the wastestream by a factor of 100 or more. But what is the ultimate fate of contaminants after they leave the ',...
'immediate vicinity of the diffusers? As material moves with the currents in Massachusetts Bay, it either settles to ',...
'the sea floor, is chemically or biologically transformed, or is eventually transported offshore. How long will it ',...
'take before contaminants in the water column are diluted below "background levels?" How are contaminants in bottom ',...
'sediment resuspended and moved by storms? Are there regions that can be identified where contaminants accumulate that ',...
'need special monitoring? How will the loading by the new treatment plant compare to existing inventories of contami-',...
'nants? How are contaminant levels in Boston Harbor expected to change after the new outfall comes on line? Are conta-',...
'minant levels in Harbor sediments already decreasing? The USGS program in Massachusetts Bay addresses these questions.',...
'  ',...
'                            Massachusetts Bay Circulation and Effluent Modeling ',...
'  ',...
'Understanding the circulation of water in Massachusetts and Cape Cod Bays is of critical importance for determining how',...
'nutrients,sediment, contaminants and other water-borne materials are transported. Numerical circulation models represent',...
'a powerful tool to build understanding of transport processes in these bays, as well as for synthesis, scenario testing ',...
'and prediction. The U.S. Geological Survey has developed a three-dimensional model of circulation in Massachusetts Bay ',...
'driven by tides, wind, river runoff, surface heating and cooling and remote forcing from the Gulf of Maine. The circula-',...
'tion calculated from this model was used as input to the HydroQual water quality model. ',...
'  ',...
'GOALS AND ACHIEVEMENTS ',...
'  ',...
' 1.Determine the mechanism for the observed mean counterclockwise circulation in Massachusetts Bay. ',...
'        Using the model as a numerical laboratory to isolate the response to specific forcing mechanisms, the Gulf of ',...
'        Maine coastal current was shown to drive southward flow that largely skirts Massachusetts Bay, while the mean',...
'        circulation in the bay proper was dominated by local wind (Blumberg, Signell and Jenter, 1993). Understanding ',...
'        the mean flow is important since it in large part determines how quickly material is flushed from the system. ');

Comments2 = sprintf('%s\n', ...
' 2.Determine the ability of three-dimensional models to reproduce observed circulation and water properties. ',...
'        The currents were simulated over an 18 month period coinciding with the Mass Bays physical oceanography',...
'        program. Comparing the modeled temperature, salinity and currents to moored observations from 25 instruments, ',...
'        it was shown that the model did a good job of reproducing the seasonal evolution of stratification, and could ',...
'        reproduce the "climate" or statistics of the currents in the bay throughout the year (Signell, Jenter and ',...
'        Blumberg, 1994). This suggests the model is appropriate for studying continuous discharge from sewage outfalls ',...
'        and for modeling the transport during winter storm events. ',...
'        The "weather" or individual current events were only reproduced during the winter. This suggests the model is ',...
'        not yet appropriate for modeling specific events during stratified periods, such as reproducing the path of a ',...
'        springtime freshet carrying red-tide organisms from the Gulf of Maine. Ongoing work described below is addressing',...
'        this issue. ',...
' 3.Determine comparative dilution of effluent due to physical processes from the existing and new outfall sites. ',...
'        Comparative dilution simulations for effluent discharged at the existing and new outfall sites were carried out ',...
'        for winter and summer periods. The simulations showed that pollutant concentrations over most of the bays will ',...
'        slightly decrease or remain about the same, while concentrations in Boston Harbor will drop dramatically. A video',...
'        of these results was widely shown at public forums on the potential impact of the new outfall, and was used as ',...
'        evidence by the U.S. Justice Department in a case concerning the effect of the outfall on endangered species on ',...
'        Stellwagen Bank.',...
' 4.Provide circuation data to drive a water quality model. ',...
'        The model provided input for HydroQual to run their water quality model over a three year period from October',...
'        1989 to December 1992.  ');

Comments3 = sprintf('%s\n', ...
'  ',...
'Final report of the this study period is available at ''http://crusty.er.usgs.gov/mbayopen/mbayopen.html'' ',...
'  ',...
'References',...
'  ',...
'    Adams, E., R. Kossik, D. J. Cosler, J. K. MacFarlane, and P. M. Gschwend, Calibration of a Transport model using',...
'    halocarbons, In Estuarine and Coastal Modeling, edited by M. L. Spaulding, pp. 380--389. American Society of Civil',...
'    Engineers, ASCE press, New York, 1990. ',...
'  ',...
'    Agency, E. P., Assessment of Potential Impact of the MWRA Outfall on Endangered Species, Technical report, EPA',...
'    Region 1, JFK Federal Building, Boston, Massachusetts 02203, 1993. ',...
'  ',...
'    Authority, M. W. R., Final Secondary Treatment Facilities Plan, Technical report, MWRA, 1988. ',...
'  ',...
'    Beckmann, A. and D. B. Haidvogel, Numerical Simulation of Flow around a Tall Isolated Seamount. Part I: Problem',...
'    Formulation and Model Accuracy, J. Phys. Oceanogr., 23, 1736--1753, 1993. ',...
'  ',...
'    Blumberg, A., Z. Ji, and C. K. Ziegler, Confirmation of the Near Field Behavior from a far field circulation model of',...
'    Massachusetts Bay, Technical report, Massachusetts Water Resources Authority, 1994. 25 pp. ',...
'  ',...
'    Blumberg, A., R. Signell, and H. Jenter, Modeling Transport Processes in the Coastal Ocean, Journal of Environmental',...
'    Engineering, 1, 31--52, 1993. ',...
'  ',...
'    Blumberg, A. F. and L. H. Kantha, Open Boundary Condition for Circulation Models, J. Hydraulic Engineering, 111,',...
'    273--255, 1985. ',...
'  ',...
'    Blumberg, A. F. and G. L. Mellor, A description of a three-dimensional coastal model, pp. 1--16, Coastal and ',...
'    Estuarine Sciences, Vol. 4. AGU, Washington, DC, 1987. ',...
'  ',...
'    Bodgen, P., P. Malanotte-Rizzoli, and R. P. Signell, Open-ocean boundary conditions from interior data: Local and',...
'    remote forcing of Massachusetts Bay, J. Geophys. Res., C12, submitted, 1995. ',...
'  ',...
'    Casulli, V., Semi-implicit finite difference methods for the two-dimensional shallow water equations, J. Computa-',...
'    tional Physics, 86, 56--74, 1990. ');

Comments4 = sprintf('%s\n', ...
'  ',...
'    Drinkwater, K., AFAP climate studies in the Scotia-Fundy Region, Technical Report 92/72, N2126, NAFO SCR, 1992. 8',...
'    pp. ',...
'  ',...
'    Galperin, B., L. H. Kantha, S. Hassid, and A. Rosati, A Quasi-equilibrium turbulent energy model for geophysical ',...
'    flows, J. Atmosph. Sci., 45, 55--62, 1988. ',...
'  ',...
'    Geyer, W., G. Gardner, W. Brown, J. Irish, B. Butman, T. Loder, and R. Signell, Physical Oceanographic Investigation',...
'    of Massachusetts and Cape Cod Bays, Technical Report MBP-92-03, Massachusetts Bays Program, U.S. EPA Region',...
'    I/Massachusetts Coastal Zone Management Office, Boston, Massachusetts, 1992. 497 pp. ',...
'  ',...
'    Geyer, W. R. and J. Ledwell, Massachusetts Bay dye study, 1994. Submitted to the Massachusetts Water Resources',...
'    Authority, Charlestown, Massachusetts. ',...
'  ',...
'    Holzwarth-Davis, T. and M. H. Taylor, Description of the 1992 Oceanographic Conditions on the Northeast Continental',...
'    Shelf, Northeast Fisheries Science Center Reference Document 93-25, NOAA/National Marine Fisheries Service, 1993.',...
'    87 p. ',...
'  ',...
'    HydroQual, I. and B. O. Sciences, A water quality model for Massachusetts and Cape Cod Bays: Calibration of the bays',...
'    eutrophication model, Technical Report NAIC0103, Massachusetts Water Resources Authority, 1995. ',...
'  ',...
'    Large, W. G. and S. Pond, Open ocean momentum flux measurements in moderate to strong winds, J. Phys. Oceanogr., 11,',...
'    324--336, 1981. ',...
'  ',...
'    Lynch, D. and C. Naimie, The M2 tide and its residual on the outer banks of the Gulf of Maine, J. Phys. Oceanogr., ',...
'    23, 2222--2253, 1993. ',...
'  ',...
'    Mellor, G. and T. Yamada, Development of a turbulence closure model for geophysical fluid problems, Rev. Geophys.',...
'    Space Phys., 20, 851--875, 1982. ');

Comments5 = sprintf('%s\n', ...
'  ',...
'    Moody, J. A., B. Butman, R. C. Beardsley, W. S. Brown, P. Daifuku, J. D. Irish, D. A. Mayer, H. O. Mofjeld, B. ',...
'    Petrie, S. Ramp, P. Smith, and W. R. Wright, Atlas of tidal elevation and current observations on the Northeast ',...
'    American Continental Shelf and Slope, U. S. Geological Survey Bulletin 1611, U.S. Geol. Surv., 1984. U.S. Government ',...
'    Printing Office, 122 pp. ',...
'  ',...
'    Shapiro, R., Linear Filtering, Mathematics of Computation, 29, 1094--1097, 1975. ',...
'  ',...
'    Signell, R. P., Tidal dynamics and dispersion around coastal headlands, Ph. D. thesis, Woods Hole Oceanogr. ',...
'    Inst./Mass. Inst. of Technol. Joint Program in Oceanography, Cambridge, Mass., 1989. 159 pp. ',...
'  ',...
'    Signell, R. P., Modeling the seasonal circulation in Massachusetts Bay, In Estuarine and Coastal Modeling, ',...
'    Proceedings of the 3rd International Conference, edited by M. L. Spaulding, pp. 578--590. American Society of ',...
'    Civil Engineers, ASCE, New York, 1994. ',...
'  ',...
'    Signell, R. P. and B. Butman, Modeling tidal exchange and dispersion in Boston Harbor, Journal of Geophysical ',...
'    Research, 97, 15,591--16,606, 1992. ',...
'  ',...
'    Smagorinsky, J., General Circulation Experiments with the Primitive Equations I. The Basic Experiment, Monthly',...
'    Weather Review, 91, 99--164, 1963. ',...
'  ',...
'    Vermersch, J., R. Beardsley, and W. Brown, Winter circulation in the western Gulf of Maine: Part 2. Current and',...
'    pressure observations, J. Phys. Oceanogr., 9, 786--784, 1979. ',...
'  ',...
'    Walton, R., R. Kossik, and R. Kapner, Bay-wide model studies for the Boston ocean outfall, In Estuarine and Coastal',...
'    Modeling, edited by M. L. Spaulding, pp. 390--399. American Society of Civil Engineers, ASCE press, New York, 1990. ',...
'  ',...
'    Weller, R., D. Rudnick, and N. J. Brink, Meteorological variability and air-sea fluxes at a closely spaced array of ',...
'    surface moorings, J. Geophys. Res., 100, 4867--4883, 1995. ');

Comments6 = sprintf('%s\n', ...
'   ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:  71.1390 W ', ...
'              East Bounding Coordinate:  69.6230 W ', ...
'              South Bounding Coordinate: 41.6479 N ', ...
'              North Bounding Coordinate: 43.2754 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Rich Signell', ...
'               384 Woods Hole Road', ...
'               U.S. Geological Survey', ...
'               Woods Hole, MA 02543 ', ...
'               USA ', ...
'               http://crusty.er.usgs.gov/rsignell.html ', ...
'               Electronic Mail Address:INTERNET > rsignell@crusty.er.usgs.gov ', ...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2 Comments3 Comments4 Comments5 Comments6];

